@@ -2,7 +2,8 @@ from pyrr import Matrix44
 import numpy
 import moderngl
 
-class DrawerTransformer:
+
+class DrawerTransform:
 
     def __init__(self, drawer):
         self.transform = Matrix44.identity(dtype=numpy.float32)
@@ -15,4 +16,4 @@ class DrawerTransformer:
     def paint_gl(self, mvp: Matrix44):
         if not self.is_visible:
             return
-        self.drawer.paint_gl(mvp * self.transform)
\ No newline at end of file
+        self.drawer.paint_gl(mvp * self.transform)
